@@ -152,7 +152,8 @@ impl AssignFolder {
                 if is_literal(&init) {
                     match *init {
                         Expr::Array(arr)
-                            if elems.len() == arr.elems.len() || has_rest_pat(&elems) =>
+                            if elems.len() == arr.elems.len()
+                                || (elems.len() < arr.elems.len() && has_rest_pat(&elems)) =>
                         {
                             let mut arr_elems = Some(arr.elems.into_iter());
                             elems.into_iter().for_each(|p| match p {
@@ -193,7 +194,12 @@ impl AssignFolder {
                                     )
                                 }
 
-                                None => {}
+                                None => {
+                                    arr_elems
+                                        .as_mut()
+                                        .expect("pattern after rest element?")
+                                        .next();
+                                }
                             });
                             return;
                         }
